Install
=======

Install into a virtualenv using pip::

    pip install django-paypal


Or using the latest version from GitHub::

    pip install git://github.com/spookylukey/django-paypal.git#egg=django-paypal

If you are using Django < 1.7, you should also install South >= 1.0.1 if you
haven't already. This is not listed as a dependency for the sake of users who
are on Django >= 1.7 and don't need it.
